@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 	"os"
+	"regexp"
 	"strings"
 
 	"github.com/ansible/receptor/pkg/controlsvc"
@@ -12,10 +13,14 @@ import (
 )
 
 type NodeCfg struct {
-	ID                       string                       `description:"Node ID. Defaults to local hostname." barevalue:"yes"`
-	DataDir                  string                       `description:"Directory in which to store node data" default:"/tmp/receptor"`
-	FirewallRules            []netceptor.FirewallRuleData `description:"Firewall Rules (see documentation for syntax)"`
-	MaxIdleConnectionTimeout string                       `description:"Max duration with no traffic before a backend connection is timed out and refreshed."`
+	ID                               string                       `description:"Node ID. Defaults to the local hostname." barevalue:"yes"`
+	DataDir                          string                       `description:"Directory in which to store node data." default:"/tmp/receptor"`
+	FirewallRules                    []netceptor.FirewallRuleData `description:"Firewall rules, see documentation for syntax."`
+	MaxIdleConnectionTimeout         string                       `description:"Maximum duration with no traffic before a backend connection is timed out and refreshed."`
+	ReceptorKubeSupportReconnect     string
+	ReceptorKubeClientsetQPS         string
+	ReceptorKubeClientsetBurst       string
+	ReceptorKubeClientsetRateLimiter string
 }
 
 func (cfg NodeCfg) Init() error {
@@ -30,6 +35,12 @@ func (cfg NodeCfg) Init() error {
 			return fmt.Errorf("no node ID specified and local host name is localhost")
 		}
 		cfg.ID = host
+	} else {
+		submitIDRegex := regexp.MustCompile(`^[.\-_@a-zA-Z0-9]*$`)
+		match := submitIDRegex.FindSubmatch([]byte(cfg.ID))
+		if match == nil {
+			return fmt.Errorf("node id can only contain a-z, A-Z, 0-9 or special characters . - _ @ but received: %s", cfg.ID)
+		}
 	}
 	if strings.ToLower(cfg.ID) == "localhost" {
 		return fmt.Errorf("node ID \"localhost\" is reserved")
