@@ -19,6 +19,7 @@ import (
 
 	"github.com/ghjm/cmdline"
 	"github.com/google/shlex"
+	"github.com/spf13/viper"
 	corev1 "k8s.io/api/core/v1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -260,7 +261,7 @@ func (kw *KubeUnit) kubeLoggingConnectionHandler(timestamps bool, sinceTime time
 	}
 	if err != nil {
 		errMsg := fmt.Sprintf("Error opening log stream for pod %s/%s. Error: %s", podNamespace, podName, err)
-		kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+		kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 		kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
 		return nil, err
@@ -328,7 +329,7 @@ func (kw *KubeUnit) kubeLoggingWithReconnect(streamWait *sync.WaitGroup, stdout
 		}
 		if err != nil {
 			errMsg := fmt.Sprintf("Error getting pod %s/%s. Error: %s", podNamespace, podName, err)
-			kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
 			// fail to get pod, no need to continue
@@ -384,11 +385,16 @@ func (kw *KubeUnit) kubeLoggingWithReconnect(streamWait *sync.WaitGroup, stdout
 			}
 
 			split := strings.SplitN(line, " ", 2)
-			timeStamp := ParseTime(split[0])
-			if !timeStamp.After(sinceTime) && !successfulWrite {
-				continue
+			msg := line
+			timestamp := ParseTime(split[0])
+			if timestamp != nil {
+				kw.GetWorkceptor().nc.GetLogger().Debug("No timestamp received, log line: '%s'", line)
+				if !timestamp.After(sinceTime) && !successfulWrite {
+					continue
+				}
+				sinceTime = *timestamp
+				msg = split[1]
 			}
-			msg := split[1]
 
 			_, err = stdout.Write([]byte(msg))
 			if err != nil {
@@ -398,7 +404,6 @@ func (kw *KubeUnit) kubeLoggingWithReconnect(streamWait *sync.WaitGroup, stdout
 				return
 			}
 			remainingRetries = retries // each time we read successfully, reset this counter
-			sinceTime = *timeStamp
 			successfulWrite = true
 		}
 
@@ -558,10 +563,10 @@ func (kw *KubeUnit) createPod(env map[string]string) error {
 		stdout, err2 := NewStdoutWriter(FileSystem{}, kw.UnitDir())
 		if err2 != nil {
 			errMsg := fmt.Sprintf("Error opening stdout file: %s", err2)
-			kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
-			return fmt.Errorf(errMsg)
+			return fmt.Errorf(errMsg) //nolint:govet,staticcheck
 		}
 		var stdoutErr error
 		var streamWait sync.WaitGroup
@@ -610,7 +615,7 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 		if err := kw.createPod(nil); err != nil {
 			if err != ErrPodCompleted {
 				errMsg := fmt.Sprintf("Error creating pod: %s", err)
-				kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+				kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 				kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
 				return
@@ -627,7 +632,7 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 			errMsg := fmt.Sprintf("Error creating pod: pod namespace is empty for pod %s",
 				podName,
 			)
-			kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
 			return
@@ -640,7 +645,7 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 			select {
 			case <-kw.GetContext().Done():
 				errMsg := fmt.Sprintf("Context Done while getting pod %s/%s. Error: %s", podNamespace, podName, kw.GetContext().Err())
-				kw.GetWorkceptor().nc.GetLogger().Warning(errMsg)
+				kw.GetWorkceptor().nc.GetLogger().Warning(errMsg) //nolint:govet
 
 				return
 			default:
@@ -661,7 +666,7 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 		}
 		if err != nil {
 			errMsg := fmt.Sprintf("Error getting pod %s/%s. Error: %s", podNamespace, podName, err)
-			kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
 			return
@@ -714,7 +719,7 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 				skipStdin = true
 			} else {
 				errMsg := fmt.Sprintf("Error opening stdin file: %s", err)
-				kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+				kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 				kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
 				return
@@ -739,7 +744,7 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 	stdout, err := NewStdoutWriter(FileSystem{}, kw.UnitDir())
 	if err != nil {
 		errMsg := fmt.Sprintf("Error opening stdout file: %s", err)
-		kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+		kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 		kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 
 		return
@@ -805,7 +810,7 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 					podName,
 					err,
 				)
-				kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+				kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 				kw.UpdateBasicStatus(WorkStateFailed, errMsg, stdout.Size())
 
 				close(stdinErrChan) // signal STDOUT goroutine to stop
@@ -815,7 +820,8 @@ func (kw *KubeUnit) runWorkUsingLogger() {
 				} else {
 					// this is probably not possible...
 					errMsg := fmt.Sprintf("Error reading stdin: %s", stdin.Error())
-					kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+					kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
+					kw.GetWorkceptor().nc.GetLogger().Error("Pod status at time of error %s", kw.pod.Status.String())
 					kw.UpdateBasicStatus(WorkStateFailed, errMsg, stdout.Size())
 
 					close(stdinErrChan) // signal STDOUT goroutine to stop
@@ -909,7 +915,18 @@ func ShouldUseReconnect(kw *KubeUnit) bool {
 	// accepted values: "enabled", "disabled", "auto".  The default is "enabled"
 	// all invalid values will assume to be "disabled"
 
-	env, ok := os.LookupEnv("RECEPTOR_KUBE_SUPPORT_RECONNECT")
+	version := viper.GetInt("version")
+	var env string
+	ok := false
+	switch version {
+	case 2:
+		env = viper.GetString("node.ReceptorKubeSupportReconnect")
+		if env != "" {
+			ok = true
+		}
+	default:
+		env, ok = os.LookupEnv("RECEPTOR_KUBE_SUPPORT_RECONNECT")
+	}
 	if ok {
 		switch env {
 		case "enabled":
@@ -995,7 +1012,7 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 	if err != nil {
 		errMsg := fmt.Sprintf("Error listening: %s", err)
 		kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
-		kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+		kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 
 		return
 	}
@@ -1004,7 +1021,15 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 	connChan := make(chan *net.TCPConn)
 	go func() {
 		conn, err := li.Accept()
-		_ = li.Close()
+		lcerr := li.Close()
+		if lcerr != nil {
+			errMsg := fmt.Sprintf("Error closing listener: %+v", lcerr)
+			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
+			cancel()
+
+			return
+		}
 		if ctx.Err() != nil {
 			return
 		}
@@ -1019,7 +1044,7 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 		if err != nil {
 			errMsg := fmt.Sprintf("Error accepting: %s", err)
 			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
-			kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 			cancel()
 
 			return
@@ -1032,7 +1057,7 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 	if err != nil {
 		errMsg := fmt.Sprintf("Error creating pod: %s", err)
 		kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
-		kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+		kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 		cancel()
 
 		return
@@ -1051,7 +1076,7 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 	stdin, err = NewStdinReader(FileSystem{}, kw.UnitDir())
 	if err != nil {
 		errMsg := fmt.Sprintf("Error opening stdin file: %s", err)
-		kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+		kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 		kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 		cancel()
 
@@ -1062,7 +1087,7 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 	stdout, err := NewStdoutWriter(FileSystem{}, kw.UnitDir())
 	if err != nil {
 		errMsg := fmt.Sprintf("Error opening stdout file: %s", err)
-		kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+		kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 		kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 		cancel()
 
@@ -1077,10 +1102,18 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 		if ctx.Err() != nil {
 			return
 		}
-		_ = conn.CloseWrite()
+		cwerr := conn.CloseWrite()
+		if cwerr != nil {
+			errMsg := fmt.Sprintf("Error closing writing side: %+v", cwerr)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
+			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
+			cancel()
+
+			return
+		}
 		if err != nil {
 			errMsg := fmt.Sprintf("Error sending stdin to pod: %s", err)
-			kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+			kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 			kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 			cancel()
 
@@ -1112,7 +1145,7 @@ func (kw *KubeUnit) runWorkUsingTCP() {
 	}
 	if err != nil {
 		errMsg := fmt.Sprintf("Error reading stdout from pod: %s", err)
-		kw.GetWorkceptor().nc.GetLogger().Error(errMsg)
+		kw.GetWorkceptor().nc.GetLogger().Error(errMsg) //nolint:govet
 		kw.UpdateBasicStatus(WorkStateFailed, errMsg, 0)
 		cancel()
 
@@ -1199,7 +1232,18 @@ func (kw *KubeUnit) connectToKube() error {
 
 	// RECEPTOR_KUBE_CLIENTSET_QPS
 	// default: 100
-	envQPS, ok := os.LookupEnv("RECEPTOR_KUBE_CLIENTSET_QPS")
+	version := viper.GetInt("version")
+	var envQPS string
+	ok := false
+	switch version {
+	case 2:
+		envQPS = viper.GetString("node.ReceptorKubeClientsetQPS")
+		if envQPS != "" {
+			ok = true
+		}
+	default:
+		envQPS, ok = os.LookupEnv("RECEPTOR_KUBE_CLIENTSET_QPS")
+	}
 	if ok {
 		qps, err := strconv.Atoi(envQPS)
 		if err != nil {
@@ -1215,7 +1259,16 @@ func (kw *KubeUnit) connectToKube() error {
 
 	// RECEPTOR_KUBE_CLIENTSET_BURST
 	// default: 10 x QPS
-	envBurst, ok := os.LookupEnv("RECEPTOR_KUBE_CLIENTSET_BURST")
+	var envBurst string
+	switch version {
+	case 2:
+		envBurst = viper.GetString("node.ReceptorKubeClientsetBurst")
+		if envBurst != "" {
+			ok = true
+		}
+	default:
+		envBurst, ok = os.LookupEnv("RECEPTOR_KUBE_CLIENTSET_BURST")
+	}
 	if ok {
 		burst, err := strconv.Atoi(envBurst)
 		if err != nil {
@@ -1231,7 +1284,16 @@ func (kw *KubeUnit) connectToKube() error {
 	// RECEPTOR_KUBE_CLIENTSET_RATE_LIMITER
 	// default: tokenbucket
 	// options: never, always, tokenbucket
-	envRateLimiter, ok := os.LookupEnv("RECEPTOR_KUBE_CLIENTSET_RATE_LIMITER")
+	var envRateLimiter string
+	switch version {
+	case 2:
+		envRateLimiter = viper.GetString("node.ReceptorKubeClientsetRateLimiter")
+		if envRateLimiter != "" {
+			ok = true
+		}
+	default:
+		envRateLimiter, ok = os.LookupEnv("RECEPTOR_KUBE_CLIENTSET_RATE_LIMITER")
+	}
 	if ok {
 		switch envRateLimiter {
 		case "never":
@@ -1576,6 +1638,10 @@ func (cfg KubeWorkerCfg) Run() error {
 }
 
 func init() {
+	version := viper.GetInt("version")
+	if version > 1 {
+		return
+	}
 	cmdline.RegisterConfigTypeForApp("receptor-workers",
 		"work-kubernetes", "Run a worker using Kubernetes", KubeWorkerCfg{}, cmdline.Section(workersSection))
 }
